<?php
/**
 * blogpecos functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package blogpecos
 */

if ( ! function_exists( 'blogpecos_setup' ) ) :
	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * Note that this function is hooked into the after_setup_theme hook, which
	 * runs before the init hook. The init hook is too late for some features, such
	 * as indicating support for post thumbnails.
	 */
	function blogpecos_setup() {
		/*
		 * Make theme available for translation.
		 * Translations can be filed in the /languages/ directory.
		 * If you're building a theme based on blogpecos, use a find and replace
		 * to change 'blogpecos' to the name of your theme in all the template files.
		 */
		load_theme_textdomain( 'blogpecos', get_template_directory() . '/languages' );

		// Add default posts and comments RSS feed links to head.
		add_theme_support( 'automatic-feed-links' );

		/*
		 * Let WordPress manage the document title.
		 * By adding theme support, we declare that this theme does not use a
		 * hard-coded <title> tag in the document head, and expect WordPress to
		 * provide it for us.
		 */
		add_theme_support( 'title-tag' );

		/*
		 * Enable support for Post Thumbnails on posts and pages.
		 *
		 * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
		 */
		add_theme_support( 'post-thumbnails' );
		add_theme_support('responsive-embeds');
		add_theme_support('wp-block-styles');
		add_theme_support('align-wide');
		add_theme_support( 'editor-styles' );


		// To use additional css
 	    add_editor_style( 'assets/css/editor-style.css' );

 	  	add_theme_support(
			'editor-font-sizes',
			array(
				array(
					'name'      => __( 'Small', 'blogpecos' ),
					'shortName' => __( 'S', 'blogpecos' ),
					'size'      => 12,
					'slug'      => 'small',
				),
				array(
					'name'      => __( 'Normal', 'blogpecos' ),
					'shortName' => __( 'M', 'blogpecos' ),
					'size'      => 14,
					'slug'      => 'normal',
				),
				array(
					'name'      => __( 'Large', 'blogpecos' ),
					'shortName' => __( 'L', 'blogpecos' ),
					'size'      => 28,
					'slug'      => 'large',
				),
				array(
					'name'      => __( 'Huge', 'blogpecos' ),
					'shortName' => __( 'XL', 'blogpecos' ),
					'size'      => 38,
					'slug'      => 'huge',
				),
			)
		);


		// This theme uses wp_nav_menu() in one location.
		register_nav_menus( array(
			'menu-1' => esc_html__( 'Primary', 'blogpecos' ),	
			'social-link' => esc_html__( 'Social media link', 'blogpecos' ),	
		) );

		/*
		 * Switch default core markup for search form, comment form, and comments
		 * to output valid HTML5.
		 */
		add_theme_support( 'html5', array(
			'search-form',
			'comment-form',
			'comment-list',
			'gallery',
			'caption',
		) );

		// Set up the WordPress core custom background feature.
		add_theme_support( 'custom-background', apply_filters( 'blogpecos_custom_background_args', array(
			'default-color' => 'eeeeee',
			'default-image' => '',
		) ) );

		// Add theme support for selective refresh for widgets.
		add_theme_support( 'customize-selective-refresh-widgets' );

		/**
		 * Add support for core custom logo.
		 *
		 * @link https://codex.wordpress.org/Theme_Logo
		 */
		add_theme_support( 'custom-logo', array(
			'height'      => 250,
			'width'       => 250,
			'flex-width'  => true,
			'flex-height' => true,
		) );
	}
endif;
add_action( 'after_setup_theme', 'blogpecos_setup' );
function blogpecos_excerpt_length( $length ) {
	return 15;
}
add_filter( 'excerpt_length', 'blogpecos_excerpt_length', 999 );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function blogpecos_content_width() {
	// This variable is intended to be overruled from themes.
	// Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
	// phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
	$GLOBALS['content_width'] = apply_filters( 'blogpecos_content_width', 640 );
}
add_action( 'after_setup_theme', 'blogpecos_content_width', 0 );




$main_content_class = 'col-sm-12 col-md-7 col-lg-8 col-xl-9';
$sidebar_content = 'col-sm-12 col-md-5 col-lg-4 col-xl-3';
if ( ! is_active_sidebar( 'sidebar-1' ) ) {
	$main_content_class = 'col-sm-12 col-md-12 col-lg-12 col-xl-12';
	$sidebar_content = 'col-sm-12 col-md-5 col-lg-4 col-xl-3';

}





/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function blogpecos_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Sidebar', 'blogpecos' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Add widgets here.', 'blogpecos' ),
		'before_widget' => '<section id="%1$s" class="widget %2$s">',
		'after_widget'  => '</section>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'blogpecos_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function blogpecos_scripts() {
	wp_enqueue_style( 'blogpecos-style', get_stylesheet_uri() );
	wp_enqueue_style( 'blogpecos-style', 'https://fonts.googleapis.com/css?family=Playfair+Display:400,700,900|Poppins:400,500,600,700,800,900&display=swap' );
	wp_enqueue_style( 'bootstrap-css', get_template_directory_uri() . '/assets/css/bootstrap.min.css' );
	wp_enqueue_style( 'fontawesome-css', get_template_directory_uri() . '/assets/css/fontawesome.min.css' );
	wp_enqueue_style( 'animate-css', get_template_directory_uri() . '/assets/css/animate.min.css' );
	wp_enqueue_style( 'slicknav-css', get_template_directory_uri() . '/assets/css/slicknav.min.css' );	
	wp_enqueue_style( 'slick-css', get_template_directory_uri() . '/assets/css/slick.css' );
	wp_enqueue_style( 'slick-theme-css', get_template_directory_uri() . '/assets/css/slick-theme.css' );
	wp_enqueue_style( 'blogpecos-main-style-css', get_template_directory_uri() . '/assets/css/style.css' );


	wp_enqueue_script( 'popper-js', get_template_directory_uri() . '/assets/js/popper.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'bootstrap-js', get_template_directory_uri() . '/assets/js/bootstrap.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'modernizr-js', get_template_directory_uri() . '/assets/js/modernizr.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'slicknav-js', get_template_directory_uri() . '/assets/js/jquery.slicknav.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'slick-js', get_template_directory_uri() . '/assets/js/slick.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'masonry-js', get_template_directory_uri() . '/assets/js/masonry.pkgd.min.js', array('jquery'), '1', true );
	wp_enqueue_script( 'blogpecos-script-js', get_template_directory_uri() . '/assets/js/scripts.js', array('jquery'), '1', true );
	wp_enqueue_script( 'blogpecos-navigation', get_template_directory_uri() . '/js/navigation.js', array(), '20151215', true );
	wp_enqueue_script( 'blogpecos-skip-link-focus-fix', get_template_directory_uri() . '/js/skip-link-focus-fix.js', array(), '20151215', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'blogpecos_scripts' );

function blogpecos_block_editor_google_fonts(){
    wp_enqueue_style( 'blogpecos_block_editor_google_fonts', 'https://fonts.googleapis.com/css?family=Playfair+Display:400,700,900|Poppins:400,500,600,700,800,900&display=swap' );
}
add_action( 'enqueue_block_editor_assets', 'blogpecos_block_editor_google_fonts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Custom hook.
 */
require get_template_directory() . '/inc/hooks/hooks.php';
/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
	require get_template_directory() . '/inc/jetpack.php';
}